@@ -1,5 +1,6 @@
 #[allow(clippy::all, dead_code)]
 pub mod hbase;
+pub use hbase::THbaseSyncClient;
 use thiserror::Error as ThisError;
 pub use thrift;
 use thrift::{
@@ -11,7 +12,7 @@ use thrift::{
 };
 
 use easy_ext::ext;
-use hbase::{BatchMutation, HbaseSyncClient, Mutation, THbaseSyncClient};
+use hbase::{BatchMutation, HbaseSyncClient, Mutation};
 use std::{
     collections::{hash_map::DefaultHasher, BTreeMap},
     hash::{Hash, Hasher},
@@ -32,12 +33,6 @@ pub type Result<T> = std::result::Result<T, Error>;
 pub enum Error {
     #[error(transparent)]
     Thift(#[from] thrift::Error),
-
-    #[error("table {0} is not enabled")]
-    TableNotEnabled(String),
-
-    #[error("table {0} does not exist")]
-    TableNotFound(String),
 }
 pub fn client(addrs: impl ToSocketAddrs) -> Result<Client> {
     let mut channel = TTcpChannel::new();
@@ -54,41 +49,18 @@ pub impl<H: THbaseSyncClient + Sized> H {
         let table_name: Vec<u8> = table_name.into();
         Ok(self.get_table_names()?.into_iter().any(|x| x == table_name))
     }
-    fn table(&mut self, table_name: &str) -> Result<Table<'_, Self>> {
-        if !self.is_table_enabled(table_name.into())? {
-            Err(Error::TableNotEnabled(table_name.to_string()))
-        } else if !self.table_exists(table_name)? {
-            Err(Error::TableNotFound(table_name.to_string()))
-        } else {
-            Ok(Table::new(table_name, self))
-        }
-    }
-}
-pub struct Table<'a, H: THbaseSyncClient> {
-    name: Vec<u8>,
-    client: &'a mut H,
-}
-
-impl<'a, H: THbaseSyncClient> Table<'a, H> {
-    pub fn new(name: impl Into<Vec<u8>>, client: &'a mut H) -> Self {
-        Self {
-            name: name.into(),
-            client,
-        }
-    }
-    pub fn put(
+    fn put(
         &mut self,
+        table_name: &str,
         row_batches: Vec<BatchMutation>,
         timestamp: Option<i64>,
         attributes: Option<Attributes>,
     ) -> Result<()> {
         let attributes = attributes.unwrap_or_default();
         let result = if let Some(timestamp) = timestamp {
-            self.client
-                .mutate_rows_ts(self.name.clone(), row_batches, timestamp, attributes)
+            self.mutate_rows_ts(table_name.into(), row_batches, timestamp, attributes)
         } else {
-            self.client
-                .mutate_rows(self.name.clone(), row_batches, attributes)
+            self.mutate_rows(table_name.into(), row_batches, attributes)
         };
         Ok(result?)
     }
